function _objectDestructuringEmpty(obj) { if (obj == null) throw new TypeError("Cannot destructure undefined"); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from "prop-types";
import { Item } from "semantic-ui-react";
import { isStringEmpty } from "../static/ObjectsUtils";
import _ from "lodash";
import { ColumnCheckBox } from "./PublicTables";

var DefaultResponsiveTableBody = function (_React$Component) {
    _inherits(DefaultResponsiveTableBody, _React$Component);

    function DefaultResponsiveTableBody(props) {
        _classCallCheck(this, DefaultResponsiveTableBody);

        var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

        _this.state = {};
        return _this;
    }

    DefaultResponsiveTableBody.prototype.modifyCheckedArray = function modifyCheckedArray(val) {
        var modifyCheckedArray = this.props.modifyCheckedArray;

        if (modifyCheckedArray) {
            modifyCheckedArray(val);
        }
    };

    DefaultResponsiveTableBody.prototype.render = function render() {
        var _this2 = this;

        _objectDestructuringEmpty(this.state);

        var _props = this.props,
            defaultResponsiveParam = _props.defaultResponsiveParam,
            headerMap = _props.headerMap,
            dataSet = _props.dataSet,
            hiddenHeaderMap = _props.hiddenHeaderMap,
            checkedIds = _props.checkedIds;
        var image = defaultResponsiveParam.image,
            header = defaultResponsiveParam.header,
            meta = defaultResponsiveParam.meta,
            description = defaultResponsiveParam.description,
            extra = defaultResponsiveParam.extra,
            unstackable = defaultResponsiveParam.unstackable;


        var checkBox = findCheckBox(headerMap, hiddenHeaderMap);

        var checkBoxDiv = React.createElement("div", null);

        if (!_.isEmpty(checkBox)) {
            var checkBoxStyle = checkBox.checkBoxStyle,
                accessor = checkBox.accessor;


            var value = dataSet[accessor] === undefined ? '' : dataSet[accessor];

            checkBoxDiv = React.createElement(ColumnCheckBox, { id: value,
                checkBoxStyle: checkBoxStyle,
                checked: _.includes(checkedIds, value),
                getCallBackId: function getCallBackId(val) {
                    return _this2.modifyCheckedArray(val);
                }
            });
        }

        return React.createElement(
            Item.Group,
            { divided: true, unstackable: unstackable },
            React.createElement(
                Item,
                null,
                renderImage(headerMap, dataSet, image, this.props, hiddenHeaderMap),
                React.createElement(
                    Item.Content,
                    null,
                    checkBoxDiv,
                    renderHeader(headerMap, dataSet, header, this.props, hiddenHeaderMap),
                    renderMeta(headerMap, dataSet, meta, this.props, hiddenHeaderMap),
                    renderDescription(headerMap, dataSet, description, this.props, hiddenHeaderMap),
                    renderExtra(headerMap, dataSet, extra, this.props, hiddenHeaderMap)
                )
            )
        );
    };

    return DefaultResponsiveTableBody;
}(React.Component);

export { DefaultResponsiveTableBody as default };
DefaultResponsiveTableBody.propTypes = process.env.NODE_ENV !== "production" ? {
    defaultResponsiveParam: PropTypes.object,
    headerMap: PropTypes.oneOfType([PropTypes.array, PropTypes.object]),
    dataSet: PropTypes.oneOfType([PropTypes.array, PropTypes.object]),
    hiddenHeaderMap: PropTypes.oneOfType([PropTypes.array, PropTypes.object])
} : {};


function renderImage(headerMap, dataSet, image, parentProps, hiddenHeaderMap) {

    if (isStringEmpty(image) || _.isEmpty(image)) {
        return null;
    }

    var accessor = image.accessor,
        size = image.size;


    var src = dataSet[accessor];

    return React.createElement(Item.Image, {
        size: isStringEmpty(size) ? "tiny" : size,
        src: src
    });
}

function renderHeader(headerMap, dataSet, header, parentProps, hiddenHeaderMap) {

    if (isStringEmpty(header) || _.isEmpty(header)) {
        return null;
    }

    var accessor = header.accessor,
        prefix = header.prefix,
        suffix = header.suffix,
        enableColFormat = header.enableColFormat;


    var content = generateDataByPreAndSuffix(dataSet, accessor, prefix, suffix);

    if (enableColFormat) {
        content = colFormatter(headerMap, hiddenHeaderMap, accessor, content, dataSet);
    }

    return React.createElement(Item.Header, {
        content: content
    });
}

function renderMeta(headerMap, dataSet, meta, parentProps, hiddenHeaderMap) {

    if (isStringEmpty(meta) || _.isEmpty(meta)) {
        return null;
    }
    var accessor = meta.accessor,
        prefix = meta.prefix,
        suffix = meta.suffix,
        enableColFormat = meta.enableColFormat;


    var content = generateDataByPreAndSuffix(dataSet, accessor, prefix, suffix);

    if (enableColFormat) {
        content = colFormatter(headerMap, hiddenHeaderMap, accessor, content, dataSet);
    }

    return React.createElement(Item.Meta, {
        content: content
    });
}

function renderDescription(headerMap, dataSet, description, parentProps, hiddenHeaderMap) {

    if (isStringEmpty(description) || _.isEmpty(description)) {
        return null;
    }
    var accessor = description.accessor,
        prefix = description.prefix,
        suffix = description.suffix,
        enableColFormat = description.enableColFormat;


    var content = generateDataByPreAndSuffix(dataSet, accessor, prefix, suffix);

    if (enableColFormat) {
        content = colFormatter(headerMap, hiddenHeaderMap, accessor, content, dataSet);
    }

    return React.createElement(Item.Description, {
        content: content
    });
}

function renderExtra(headerMap, dataSet, extra, parentProps, hiddenHeaderMap) {

    if (isStringEmpty(extra) || _.isEmpty(extra)) {
        return null;
    }

    var accessor = extra.accessor,
        prefix = extra.prefix,
        suffix = extra.suffix,
        enableColFormat = extra.enableColFormat;


    var content = generateDataByPreAndSuffix(dataSet, accessor, prefix, suffix);

    if (enableColFormat) {
        content = colFormatter(headerMap, hiddenHeaderMap, accessor, content, dataSet);
    }

    return React.createElement(Item.Extra, {
        content: content
    });
}

function generateDataByPreAndSuffix(dataSet, accessor, prefix, suffix) {
    //console.log(dataSet[accessor])
    var content = isStringEmpty(dataSet[accessor]) ? "" : dataSet[accessor];

    if (!isStringEmpty(prefix)) {
        content = prefix + content;
    }

    if (!isStringEmpty(suffix)) {
        content = content + suffix;
    }

    return content;
}

function colFormatter(headerMap, hiddenHeaderMap, responsiveAccessor, content, dataSet) {

    var colFormat = _.findLast(headerMap, function (element) {
        var accessor = element.props.accessor;

        return accessor === responsiveAccessor;
    });

    if (_.isEmpty(colFormat)) {
        colFormat = _.findLast(hiddenHeaderMap, function (element) {
            var accessor = element.props.accessor;

            return accessor === responsiveAccessor;
        });
    }

    if (!_.isEmpty(colFormat)) {
        var columnFormat = colFormat.props.columnFormat;


        if (columnFormat) {
            return columnFormat(content, dataSet);
        }
    }

    return "";
}

function findCheckBox(headerMap, hiddenHeaderMap) {

    var checkBox = _.findLast(headerMap, function (element) {
        var colAsCheckBox = element.props.colAsCheckBox;

        return colAsCheckBox === true;
    });

    if (_.isEmpty(checkBox)) {
        checkBox = _.findLast(hiddenHeaderMap, function (element) {
            var colAsCheckBox = element.props.colAsCheckBox;

            return colAsCheckBox === true;
        });
    }

    if (!_.isEmpty(checkBox)) {

        return checkBox.props;
    }

    return null;
}