"use strict";

exports.__esModule = true;
exports.default = undefined;

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _propTypes = require("prop-types");

var _propTypes2 = _interopRequireDefault(_propTypes);

var _semanticUiReact = require("semantic-ui-react");

var _ObjectsUtils = require("../static/ObjectsUtils");

var _lodash = require("lodash");

var _lodash2 = _interopRequireDefault(_lodash);

var _PublicTables = require("./PublicTables");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectDestructuringEmpty(obj) { if (obj == null) throw new TypeError("Cannot destructure undefined"); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var DefaultResponsiveTableBody = function (_React$Component) {
    _inherits(DefaultResponsiveTableBody, _React$Component);

    function DefaultResponsiveTableBody(props) {
        _classCallCheck(this, DefaultResponsiveTableBody);

        var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

        _this.state = {};
        return _this;
    }

    DefaultResponsiveTableBody.prototype.modifyCheckedArray = function modifyCheckedArray(val) {
        var modifyCheckedArray = this.props.modifyCheckedArray;

        if (modifyCheckedArray) {
            modifyCheckedArray(val);
        }
    };

    DefaultResponsiveTableBody.prototype.render = function render() {
        var _this2 = this;

        _objectDestructuringEmpty(this.state);

        var _props = this.props,
            defaultResponsiveParam = _props.defaultResponsiveParam,
            headerMap = _props.headerMap,
            dataSet = _props.dataSet,
            hiddenHeaderMap = _props.hiddenHeaderMap,
            checkedIds = _props.checkedIds;
        var image = defaultResponsiveParam.image,
            header = defaultResponsiveParam.header,
            meta = defaultResponsiveParam.meta,
            description = defaultResponsiveParam.description,
            extra = defaultResponsiveParam.extra,
            unstackable = defaultResponsiveParam.unstackable;


        var checkBox = findCheckBox(headerMap, hiddenHeaderMap);

        var checkBoxDiv = _react2.default.createElement("div", null);

        if (!_lodash2.default.isEmpty(checkBox)) {
            var checkBoxStyle = checkBox.checkBoxStyle,
                accessor = checkBox.accessor;


            var value = dataSet[accessor] === undefined ? '' : dataSet[accessor];

            checkBoxDiv = _react2.default.createElement(_PublicTables.ColumnCheckBox, { id: value,
                checkBoxStyle: checkBoxStyle,
                checked: _lodash2.default.includes(checkedIds, value),
                getCallBackId: function getCallBackId(val) {
                    return _this2.modifyCheckedArray(val);
                }
            });
        }

        return _react2.default.createElement(
            _semanticUiReact.Item.Group,
            { divided: true, unstackable: unstackable },
            _react2.default.createElement(
                _semanticUiReact.Item,
                null,
                renderImage(headerMap, dataSet, image, this.props, hiddenHeaderMap),
                _react2.default.createElement(
                    _semanticUiReact.Item.Content,
                    null,
                    checkBoxDiv,
                    renderHeader(headerMap, dataSet, header, this.props, hiddenHeaderMap),
                    renderMeta(headerMap, dataSet, meta, this.props, hiddenHeaderMap),
                    renderDescription(headerMap, dataSet, description, this.props, hiddenHeaderMap),
                    renderExtra(headerMap, dataSet, extra, this.props, hiddenHeaderMap)
                )
            )
        );
    };

    return DefaultResponsiveTableBody;
}(_react2.default.Component);

exports.default = DefaultResponsiveTableBody;
DefaultResponsiveTableBody.propTypes = process.env.NODE_ENV !== "production" ? {
    defaultResponsiveParam: _propTypes2.default.object,
    headerMap: _propTypes2.default.oneOfType([_propTypes2.default.array, _propTypes2.default.object]),
    dataSet: _propTypes2.default.oneOfType([_propTypes2.default.array, _propTypes2.default.object]),
    hiddenHeaderMap: _propTypes2.default.oneOfType([_propTypes2.default.array, _propTypes2.default.object])
} : {};


function renderImage(headerMap, dataSet, image, parentProps, hiddenHeaderMap) {

    if ((0, _ObjectsUtils.isStringEmpty)(image) || _lodash2.default.isEmpty(image)) {
        return null;
    }

    var accessor = image.accessor,
        size = image.size;


    var src = dataSet[accessor];

    return _react2.default.createElement(_semanticUiReact.Item.Image, {
        size: (0, _ObjectsUtils.isStringEmpty)(size) ? "tiny" : size,
        src: src
    });
}

function renderHeader(headerMap, dataSet, header, parentProps, hiddenHeaderMap) {

    if ((0, _ObjectsUtils.isStringEmpty)(header) || _lodash2.default.isEmpty(header)) {
        return null;
    }

    var accessor = header.accessor,
        prefix = header.prefix,
        suffix = header.suffix,
        enableColFormat = header.enableColFormat;


    var content = generateDataByPreAndSuffix(dataSet, accessor, prefix, suffix);

    if (enableColFormat) {
        content = colFormatter(headerMap, hiddenHeaderMap, accessor, content, dataSet);
    }

    return _react2.default.createElement(_semanticUiReact.Item.Header, {
        content: content
    });
}

function renderMeta(headerMap, dataSet, meta, parentProps, hiddenHeaderMap) {

    if ((0, _ObjectsUtils.isStringEmpty)(meta) || _lodash2.default.isEmpty(meta)) {
        return null;
    }
    var accessor = meta.accessor,
        prefix = meta.prefix,
        suffix = meta.suffix,
        enableColFormat = meta.enableColFormat;


    var content = generateDataByPreAndSuffix(dataSet, accessor, prefix, suffix);

    if (enableColFormat) {
        content = colFormatter(headerMap, hiddenHeaderMap, accessor, content, dataSet);
    }

    return _react2.default.createElement(_semanticUiReact.Item.Meta, {
        content: content
    });
}

function renderDescription(headerMap, dataSet, description, parentProps, hiddenHeaderMap) {

    if ((0, _ObjectsUtils.isStringEmpty)(description) || _lodash2.default.isEmpty(description)) {
        return null;
    }
    var accessor = description.accessor,
        prefix = description.prefix,
        suffix = description.suffix,
        enableColFormat = description.enableColFormat;


    var content = generateDataByPreAndSuffix(dataSet, accessor, prefix, suffix);

    if (enableColFormat) {
        content = colFormatter(headerMap, hiddenHeaderMap, accessor, content, dataSet);
    }

    return _react2.default.createElement(_semanticUiReact.Item.Description, {
        content: content
    });
}

function renderExtra(headerMap, dataSet, extra, parentProps, hiddenHeaderMap) {

    if ((0, _ObjectsUtils.isStringEmpty)(extra) || _lodash2.default.isEmpty(extra)) {
        return null;
    }

    var accessor = extra.accessor,
        prefix = extra.prefix,
        suffix = extra.suffix,
        enableColFormat = extra.enableColFormat;


    var content = generateDataByPreAndSuffix(dataSet, accessor, prefix, suffix);

    if (enableColFormat) {
        content = colFormatter(headerMap, hiddenHeaderMap, accessor, content, dataSet);
    }

    return _react2.default.createElement(_semanticUiReact.Item.Extra, {
        content: content
    });
}

function generateDataByPreAndSuffix(dataSet, accessor, prefix, suffix) {
    //console.log(dataSet[accessor])
    var content = (0, _ObjectsUtils.isStringEmpty)(dataSet[accessor]) ? "" : dataSet[accessor];

    if (!(0, _ObjectsUtils.isStringEmpty)(prefix)) {
        content = prefix + content;
    }

    if (!(0, _ObjectsUtils.isStringEmpty)(suffix)) {
        content = content + suffix;
    }

    return content;
}

function colFormatter(headerMap, hiddenHeaderMap, responsiveAccessor, content, dataSet) {

    var colFormat = _lodash2.default.findLast(headerMap, function (element) {
        var accessor = element.props.accessor;

        return accessor === responsiveAccessor;
    });

    if (_lodash2.default.isEmpty(colFormat)) {
        colFormat = _lodash2.default.findLast(hiddenHeaderMap, function (element) {
            var accessor = element.props.accessor;

            return accessor === responsiveAccessor;
        });
    }

    if (!_lodash2.default.isEmpty(colFormat)) {
        var columnFormat = colFormat.props.columnFormat;


        if (columnFormat) {
            return columnFormat(content, dataSet);
        }
    }

    return "";
}

function findCheckBox(headerMap, hiddenHeaderMap) {

    var checkBox = _lodash2.default.findLast(headerMap, function (element) {
        var colAsCheckBox = element.props.colAsCheckBox;

        return colAsCheckBox === true;
    });

    if (_lodash2.default.isEmpty(checkBox)) {
        checkBox = _lodash2.default.findLast(hiddenHeaderMap, function (element) {
            var colAsCheckBox = element.props.colAsCheckBox;

            return colAsCheckBox === true;
        });
    }

    if (!_lodash2.default.isEmpty(checkBox)) {

        return checkBox.props;
    }

    return null;
}
module.exports = exports["default"];