'use strict';

exports.__esModule = true;
exports.ColumnCheckBox = exports.PublicTableFooter = exports.default = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _semanticUiReact = require('semantic-ui-react');

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _PublicTableFooters = require('./PublicTableFooters');

var _ObjectsUtils = require('../static/ObjectsUtils');

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _reactResizeDetector = require('react-resize-detector');

var _reactResizeDetector2 = _interopRequireDefault(_reactResizeDetector);

var _DefaultResponsiveTableBody = require('./DefaultResponsiveTableBody');

var _DefaultResponsiveTableBody2 = _interopRequireDefault(_DefaultResponsiveTableBody);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

//import update from "immutability-helper";


/**
 *
 * @author:RockyChen
 *
 * @abstract:
 *  Universal table element
 *
 * @style:
 *  3.unstackable: PropTypes.bool,
 *  4.celled: PropTypes.bool,
 *  5.basic: PropTypes.string,//very
 *  6.collapsing:
 *  7.compact :  a table may sometimes need to be more compact to make more rows visible at a time.
 *  8.definition :A table may be formatted to emphasize a first column that defines a rows content.
 *  9.inverted: A table's colors can be inverted.
 *  10.fixed.bool: A table may sometimes need to be more padded for legibility.
 *  11.singleLine: A table can specify that its cell contents should remain on a single line and not wrap.
 *  12.sortable : A table may allow a user to sort contents by clicking on a table header.
 *  13.stackable: A table can specify how it stacks table content responsively.
 *
 *
 *
 * @checkOptions:
 *  1.checkOptions.showAllCheck=true // show "check all" button on the header, default = false;
 *  2.checkOptions.checkOnSelect=true // unimplemented --- wait for spare time
 *  3.checkOptions.checkedCallBackFunction = ()=>void(0)
 *
 * @pagination : boolean, if true, just show the pagination bar and re-calculate the data set
 *
 * @onRowClickFunc : call back function of click a row, give back the data of clicking row.
 */
var PublicTables = function (_React$Component) {
    _inherits(PublicTables, _React$Component);

    function PublicTables(props) {
        _classCallCheck(this, PublicTables);

        var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

        _this.onResize = function (width, height) {

            _this.setState({
                tableWidth: width,
                tableHeight: height
            });
        };

        _this.handlePageSizeChange = function (value) {
            _this.setState({
                pageSize: parseInt(value, 10)
            });
        };

        _this.handlePageClick = function (data) {
            //console.log(data);
            _this.setState({
                currentPage: data
            });

            if (_this.props.onPageChangeCallBack) {
                _this.props.onPageChangeCallBack(data);
            }
        };

        _this.toggleCheckAll = function (accessor, dataSet) {
            var _this$state = _this.state,
                allChecked = _this$state.allChecked,
                checkedIds = _this$state.checkedIds;
            //console.log(accessor)

            _this.setState({ allChecked: !allChecked });

            //let currentPageList = dataSet;

            if (!allChecked === true) {
                for (var i = 0; i < dataSet.length; i++) {
                    checkedIds.push(dataSet[i][accessor]);
                }
                _this.setState({ checkedIds: checkedIds });
                //if call back function is not undefined , call it
                if (_this.props.checkedCallBackFunction) {
                    _this.props.checkedCallBackFunction(checkedIds);
                }
            } else {
                _this.setState({ checkedIds: [] });
                //if call back function is not undefined , call it
                if (_this.props.checkedCallBackFunction) {
                    _this.props.checkedCallBackFunction([]);
                }
            }
        };

        var pageSize = getPageDefaultSize(props);
        _this.state = {
            data: props.data,
            sortedData: props.data,
            showAllCheck: props.showAllCheck === undefined ? false : props.showAllCheck,
            pagination: props.pagination === undefined ? false : props.pagination,
            pageSize: pageSize,
            allChecked: false,
            checkedIds: props.defaultCheckedIds === undefined ? [] : props.defaultCheckedIds,
            currentPage: 1,
            column: null,
            direction: null,
            key: (0, _ObjectsUtils.getRandomNumber)(1000000000),
            bodyKey: (0, _ObjectsUtils.getRandomNumber)(1000000000),
            tableWidth: -1,
            tableHeight: -1
        };
        return _this;
    }

    PublicTables.prototype.componentDidUpdate = function componentDidUpdate(prevProps, prevState, snapshot) {
        var _props = this.props,
            data = _props.data,
            defaultCheckedIds = _props.defaultCheckedIds,
            fakePagination = _props.fakePagination;


        if (data !== prevProps.data) {

            this.setState({
                data: data,
                sortedData: data
            });

            if (fakePagination) {
                // if is fake Pagination, means need to refresh the body of table
                this.setState({
                    bodyKey: (0, _ObjectsUtils.getRandomNumber)(1000000000)
                });
            } else {
                this.setState({ // otherwise need to refresh everything
                    key: (0, _ObjectsUtils.getRandomNumber)(1000000000)
                });
            }
        }

        if (defaultCheckedIds !== prevProps.defaultCheckedIds) {
            this.setState({
                checkedIds: defaultCheckedIds
            });
        }
    };

    //modify the checked list


    PublicTables.prototype.modifyCheckedArray = function modifyCheckedArray(id) {
        //console.log(id)
        var checkedIds = this.state.checkedIds;

        var index = checkedIds.indexOf(id);
        if (index < 0) {
            checkedIds.push(id);
        } else {
            checkedIds.splice(index, 1);
        }
        this.setState({
            checkedIds: checkedIds
        });
        //if call back function is not undefined , call it
        if (this.props.checkedCallBackFunction) {
            this.props.checkedCallBackFunction(checkedIds);
        }
    };

    /*
     *   currentPage*pageSize  is the beginning of a page
     *   (currentPage+1)*pageSize  is the end of a page
     *
     *   currentPage provided by semantic is beginning from 1
     *   but array index of javascript is beginning from 0
     *   that is why I use (currentPage-1)
     */


    PublicTables.prototype.TablePagination = function TablePagination(ParamArr) {
        var _state = this.state,
            currentPage = _state.currentPage,
            pageSize = _state.pageSize;

        var totalPage = Math.ceil((ParamArr === undefined ? 1 : ParamArr.length) / pageSize);

        //in case total page is less than current page
        var currentByTotal = totalPage < currentPage ? 1 : currentPage;

        return ParamArr.slice((currentByTotal - 1) * pageSize, currentByTotal * pageSize);
    };

    // onPageChange


    /* check all button click
       using given accessor
    */


    //onRowSelectAndClick
    PublicTables.prototype.onRowSelectCallBack = function onRowSelectCallBack(column) {
        if (this.props.onRowSelectCallBack) {
            this.props.onRowSelectCallBack(column);
        }
    };

    PublicTables.prototype.onHeaderClickCallBack = function onHeaderClickCallBack(clickedColumn, sortable, _onHeaderClickCallBack, notSortableColumn) {

        if (sortable && !notSortableColumn) {
            // sort it anyway
            this.handleSort(clickedColumn, sortable);
        }

        if (_onHeaderClickCallBack) {
            // then we decide whether we have to use this callback
            _onHeaderClickCallBack(clickedColumn);
        }
    };

    PublicTables.prototype.handleSort = function handleSort(clickedColumn, sortable) {

        if (sortable) {
            var _state2 = this.state,
                column = _state2.column,
                sortedData = _state2.sortedData,
                direction = _state2.direction;


            if (column !== clickedColumn) {
                this.setState({
                    column: clickedColumn,
                    sortedData: _lodash2.default.sortBy(sortedData, [clickedColumn]),
                    direction: 'ascending'
                });

                return;
            }

            this.setState({
                sortedData: sortedData.reverse(),
                direction: direction === 'ascending' ? 'descending' : 'ascending'
            });
        }
    };

    PublicTables.prototype.onCellSelected = function onCellSelected(elm, value, column) {
        //console.log(elm.props.onCellSelectCallBack)
        if (elm.props.onCellSelectCallBack) {
            elm.props.onCellSelectCallBack(value, column);
        }
    };

    PublicTables.prototype.render = function render() {
        var _this2 = this;

        var _state3 = this.state,
            sortedData = _state3.sortedData,
            pageSize = _state3.pageSize,
            key = _state3.key,
            allChecked = _state3.allChecked,
            showAllCheck = _state3.showAllCheck,
            pagination = _state3.pagination,
            currentPage = _state3.currentPage,
            direction = _state3.direction,
            bodyKey = _state3.bodyKey,
            tableWidth = _state3.tableWidth;


        var colCount = 0; // calculate the total columns
        var headerMap = []; //headerMap, check props
        var hiddenHeaderMap = [];
        var footerMap = [];

        var dataSet = Object.assign([], sortedData); //always assign to a new Array to avoid pointer issue.

        _react2.default.Children.forEach(this.props.children, function (column, i) {

            //console.log(column, column.type.name);
            // type should be PublicTableHeaders tableHeader, if cannot read element type , read default props
            var tableElementType = column.props.tableElementType;
            if (column.type.name === "PublicTableHeaders" || tableElementType === "PublicTableHeaders") {

                /*
                 * TODO: customization filter function using loadash  needed:
                 * give a dataSet as arg[], give a dataSet Back, that means can write
                 * customized filters such as :
                 * 1 using 'greater than' or 'less than',
                 * 2 filterText === colVal || something || something
                 */
                var _column$props = column.props,
                    accessor = _column$props.accessor,
                    filterContext = _column$props.filterContext,
                    isHidden = _column$props.isHidden;
                //filter dataSet by accessor and filterContext

                if (filterContext !== undefined && filterContext !== null && filterContext !== '') {
                    //console.log(filterContext)
                    if (_lodash2.default.isFunction(filterContext)) {
                        var returnArr = filterContext(dataSet);
                        if (_lodash2.default.isArray(returnArr)) {
                            dataSet = returnArr;
                        }
                    } else {
                        dataSet = filterDataByFilterContext(accessor, filterContext, dataSet);
                    }
                }

                //only push not hidden element
                if (isHidden !== true) {
                    headerMap.push(column); // push unhidden columns in array for looping
                    colCount += 1; //calculate total unhidden columns
                } else {
                    hiddenHeaderMap.push(column);
                }
            }
            // type should be CustomizedFooter , if cannot read element type , read default props
            if (column.type.name === "CustomizedFooter" || tableElementType === "CustomizedFooter") {
                _react2.default.Children.forEach(column.props.children, function (foot, i) {
                    footerMap.push(foot);
                });
            }
        });

        var paginationProps = this.props.paginationProps;

        //console.log(headerMap, footerMap);
        // pagination footer if is false don't show it

        var paginationFooter = _react2.default.createElement(_semanticUiReact.Table.Row, null);

        if (!_lodash2.default.includes([true, "primary", "secondary"], pagination) && footerMap.length > 0) {
            paginationFooter = _react2.default.createElement(_PublicTableFooters.NoPaginationUserFooter, { colCount: colCount, footerMap: footerMap });
        }

        var _props2 = this.props,
            fakePagination = _props2.fakePagination,
            fakeDataSum = _props2.fakeDataSum;


        if (fakePagination) {
            // fake pagination don't need to manipulate data inside of this table utils
            //if need pagination or pagination type is primary,
            //add new footer include pagination menu and calculate data set
            if (pagination === true || pagination === "primary" || pagination === "secondary") {
                paginationFooter = _react2.default.createElement(_PublicTableFooters.PaginationFooterSecondary, {
                    colCount: colCount,
                    dataCount: fakeDataSum,
                    pageSize: pageSize,
                    currentPage: currentPage,
                    handlePageClick: function handlePageClick(val) {
                        return _this2.handlePageClick(val);
                    },
                    footerMap: footerMap,
                    paginationProps: paginationProps
                });
                // dataSet = this.TablePagination(dataSet)
            }
        } else {
            //if need pagination or pagination type is primary,
            //add new footer include pagination menu and calculate data set
            if (pagination === true || pagination === "primary") {
                paginationFooter = _react2.default.createElement(_PublicTableFooters.PaginationFooter, {
                    colCount: colCount,
                    dataCount: dataSet.length,
                    pageSize: pageSize,
                    currentPage: currentPage,
                    handlePageClick: function handlePageClick(val) {
                        return _this2.handlePageClick(val);
                    },
                    onPageSizeChange: function onPageSizeChange(val) {
                        return _this2.handlePageSizeChange(val);
                    },
                    footerMap: footerMap,
                    paginationProps: paginationProps
                });
                //dataSet pagination, based on current page
                dataSet = this.TablePagination(dataSet);
            } else if (pagination === "secondary") {
                paginationFooter = _react2.default.createElement(_PublicTableFooters.PaginationFooterSecondary, {
                    colCount: colCount,
                    dataCount: dataSet.length,
                    pageSize: pageSize,
                    currentPage: currentPage,
                    handlePageClick: function handlePageClick(val) {
                        return _this2.handlePageClick(val);
                    },
                    footerMap: footerMap,
                    paginationProps: paginationProps
                });
                dataSet = this.TablePagination(dataSet);
            }
        }

        var _props3 = this.props,
            selectable = _props3.selectable,
            color = _props3.color,
            unstackable = _props3.unstackable,
            celled = _props3.celled,
            basic = _props3.basic,
            collapsing = _props3.collapsing,
            compact = _props3.compact,
            definition = _props3.definition,
            inverted = _props3.inverted,
            fixed = _props3.fixed,
            padded = _props3.padded,
            singleLine = _props3.singleLine,
            sortable = _props3.sortable,
            stackable = _props3.stackable,
            verticalAlign = _props3.verticalAlign,
            tableSize = _props3.tableSize,
            attached = _props3.attached,
            style = _props3.style,
            columns = _props3.columns,
            striped = _props3.striped; // most common styles of semantic ui

        return _react2.default.createElement(
            _semanticUiReact.Table,
            {
                key: key,
                celled: celled,
                attached: attached,
                unstackable: unstackable,
                selectable: selectable,
                color: color,
                basic: basic,
                collapsing: collapsing,
                compact: compact,
                definition: definition,
                inverted: inverted,
                fixed: fixed,
                padded: padded,
                singleLine: singleLine,
                sortable: true,
                stackable: stackable,
                verticalAlign: verticalAlign,
                size: tableSize,
                style: style,
                columns: columns,
                striped: striped
            },
            _react2.default.createElement(
                _semanticUiReact.Table.Header,
                null,
                _react2.default.createElement(
                    _semanticUiReact.Table.Row,
                    null,
                    headerMap.map(function (column, i) {
                        var _column$props2 = column.props,
                            accessor = _column$props2.accessor,
                            colAsCheckBox = _column$props2.colAsCheckBox,
                            textAlign = _column$props2.textAlign,
                            collapsing = _column$props2.collapsing,
                            customizeText = _column$props2.customizeText,
                            onHeaderClickCallBack = _column$props2.onHeaderClickCallBack,
                            notSortable = _column$props2.notSortable;

                        var header = column.props.header === undefined ? 'undefined' : column.props.header;
                        //TODO: structured table :  const rowSpan = column.props.rowSpan;

                        // if customizeText is not none, call this function
                        if (customizeText) {
                            //call back function send header value and row object
                            header = customizeText(header, column);
                        }

                        /*
                           if and only if this column is shown as a check box and header shown as check all
                           return the header as a checked all
                        */
                        if (showAllCheck === true && colAsCheckBox === true) {

                            return _react2.default.createElement(
                                _semanticUiReact.Table.HeaderCell,
                                { collapsing: true, key: i },
                                _react2.default.createElement(_semanticUiReact.Checkbox, {
                                    onChange: function onChange() {
                                        return _this2.toggleCheckAll(accessor, dataSet);
                                    },
                                    checked: allChecked
                                })
                            );
                        } else {

                            //if this column can be sorted

                            return _react2.default.createElement(
                                _semanticUiReact.Table.HeaderCell,
                                {
                                    key: i,
                                    collapsing: collapsing,
                                    textAlign: textAlign,
                                    sorted: column === accessor ? direction : null,
                                    onClick: function onClick() {
                                        return _this2.onHeaderClickCallBack(accessor, sortable, onHeaderClickCallBack, notSortable);
                                    }
                                },
                                header,
                                ' ',
                                notSortable || !sortable ? null : _react2.default.createElement(_semanticUiReact.Icon, { name: 'sort' })
                            );
                        }
                    })
                )
            ),
            _react2.default.createElement(
                _semanticUiReact.Table.Body,
                { key: bodyKey },
                //first loop for rendering rows
                dataSet.map(function (column, i) {
                    //console.log(i, column)

                    var checkedIds = _this2.state.checkedIds;
                    var _props4 = _this2.props,
                        rowHighLightFunction = _props4.rowHighLightFunction,
                        rowRenderCallback = _props4.rowRenderCallback,
                        defaultResponsiveParam = _props4.defaultResponsiveParam;


                    var isHighLight = false;

                    var newRow = "";

                    if (rowHighLightFunction) {
                        isHighLight = rowHighLightFunction(column);
                    }

                    /*
                     * if we set a default responsive param
                     *
                     * return a <Item/> instead of table
                     */
                    if (!_lodash2.default.isEmpty(defaultResponsiveParam)) {
                        var widthThreshold = defaultResponsiveParam.widthThreshold;


                        var minimumWidth = (0, _ObjectsUtils.isStringEmpty)(widthThreshold) ? 480 : _lodash2.default.parseInt(widthThreshold, 10);

                        // if the size less than equals the threshold
                        if (tableWidth <= minimumWidth) {
                            return _react2.default.createElement(
                                _semanticUiReact.Table.Row,
                                { key: i },
                                _react2.default.createElement(
                                    _semanticUiReact.Table.Cell,
                                    { colSpan: colCount },
                                    _react2.default.createElement(_DefaultResponsiveTableBody2.default, _extends({}, _this2.props, {
                                        headerMap: headerMap,
                                        dataSet: column,
                                        hiddenHeaderMap: hiddenHeaderMap,
                                        checkedIds: checkedIds,
                                        modifyCheckedArray: function modifyCheckedArray(val) {
                                            return _this2.modifyCheckedArray(val);
                                        }
                                    }))
                                )
                            );
                        }
                    }

                    /*
                     * the call back is the whole row.
                     *
                     * if have not return anything, when do not re-render this
                     *
                     * if have something, we re-render
                     *
                     */
                    if (rowRenderCallback) {
                        newRow = rowRenderCallback(column, i);

                        if (!(0, _ObjectsUtils.isStringEmpty)(newRow)) {
                            return newRow;
                        }
                    }

                    return _react2.default.createElement(
                        _semanticUiReact.Table.Row,
                        { key: i, onClick: function onClick() {
                                return _this2.onRowSelectCallBack(column);
                            },
                            positive: isHighLight },
                        //second loop for rendering cells
                        headerMap.map(function (elm, j) {
                            var _elm$props = elm.props,
                                checkBoxStyle = _elm$props.checkBoxStyle,
                                selectable = _elm$props.selectable,
                                accessor = _elm$props.accessor,
                                columnAlign = _elm$props.columnAlign,
                                colAsCheckBox = _elm$props.colAsCheckBox,
                                columnFormat = _elm$props.columnFormat,
                                filterContext = _elm$props.filterContext,
                                highLightFilterText = _elm$props.highLightFilterText;

                            //get value by accessor

                            var value = column[accessor] === undefined ? '' : column[accessor];

                            // if formatter is not none, call this function
                            if (columnFormat) {
                                //call back function send cell value and row object
                                value = columnFormat(value, column);
                            } else {
                                if (highLightFilterText) {
                                    value = getHighlightedText(value, filterContext);
                                }
                            }

                            // if this column is set to be a check box ,then return a check box
                            if (colAsCheckBox === true) {
                                return _react2.default.createElement(
                                    _semanticUiReact.Table.Cell,
                                    { collapsing: true, key: j, textAlign: columnAlign,
                                        selectable: false },
                                    _react2.default.createElement(ColumnCheckBox, { id: value,
                                        checkBoxStyle: checkBoxStyle,
                                        checked: _lodash2.default.includes(checkedIds, value),
                                        getCallBackId: function getCallBackId(val) {
                                            return _this2.modifyCheckedArray(val);
                                        }
                                    })
                                );
                            } else {
                                // if it is not a check box column, return as a simple column
                                return _react2.default.createElement(
                                    _semanticUiReact.Table.Cell,
                                    { key: j,
                                        textAlign: columnAlign,
                                        selectable: selectable,
                                        onClick: function onClick() {
                                            return _this2.onCellSelected(elm, value, column);
                                        }
                                    },
                                    value
                                );
                            }
                        })
                    );
                })
            ),
            _react2.default.createElement(
                _semanticUiReact.Table.Footer,
                null,
                paginationFooter
            ),
            _react2.default.createElement(
                _semanticUiReact.Table.Footer,
                null,
                _react2.default.createElement(
                    _semanticUiReact.Table.Row,
                    null,
                    _react2.default.createElement(
                        _semanticUiReact.Table.Cell,
                        { colSpan: colCount },
                        _react2.default.createElement(_reactResizeDetector2.default, {
                            handleWidth: true,
                            handleHeight: true,
                            onResize: this.onResize
                        })
                    )
                )
            )
        );
    };

    return PublicTables;
}(_react2.default.Component);

exports.default = PublicTables;
PublicTables.propTypes = process.env.NODE_ENV !== "production" ? {
    /**
     * data format is JSON array
     * [ {name:"Tom"},{age:16} ]
     */
    data: _propTypes2.default.array.isRequired,
    /**
     * first header cell shown as a select all check box
     */
    showAllCheck: _propTypes2.default.bool,
    /**
     * pass the value of internal onCheckBoxChange
     * <PublicTables data={dummy_data}  checkedCallBackFunction={(val) => console.log(val)}>
     */
    checkedCallBackFunction: _propTypes2.default.func,
    /**
     * pass the selected row data
     */
    onRowSelectCallBack: _propTypes2.default.func,
    /**
     * 2 different type of pagination bar
     */
    pagination: _propTypes2.default.oneOfType([_propTypes2.default.bool, _propTypes2.default.oneOf(["primary", "secondary"])]),
    /**
     * currently only support hard-coded : 10 ,20 , 50
     */
    pageSize: _propTypes2.default.PropTypes.number,
    /**
     * should combine with function onRowSelectCallBack
     * <PublicTables selectable onRowSelectCallBack={(row)=>console.log(row)}>
     */
    selectable: _propTypes2.default.bool,
    /**
     * semantic-ui builtin prop
     * using Lodash sort method.
     */
    sortable: _propTypes2.default.bool,
    /**
     * semantic-ui builtin prop
     * red,orange,yellow,olive,green,teal,blue,violet,purple,pink,brown,grey,black
     */
    color: _propTypes2.default.PropTypes.oneOf(["red", "orange", "yellow", "olive", "green", "teal", "blue", "violet", "purple", "pink", "brown", "grey", "black"]),
    /**
     * semantic-ui builtin prop
     * small,large
     */
    tableSize: _propTypes2.default.PropTypes.oneOf(["small", "large"]),
    /**
     * semantic-ui builtin prop
     */
    unstackable: _propTypes2.default.bool,
    /**
     * semantic-ui builtin prop
     */
    celled: _propTypes2.default.bool,
    /**
     * semantic-ui builtin prop
     */
    basic: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.bool]), //"very"
    /**
     * semantic-ui builtin prop
     */
    collapsing: _propTypes2.default.bool,
    /**
     * semantic-ui builtin prop
     */
    compact: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.bool]), //"very"
    /**
     * semantic-ui builtin prop
     */
    definition: _propTypes2.default.bool,
    /**
     * semantic-ui builtin prop
     */
    inverted: _propTypes2.default.bool,
    /**
     * semantic-ui builtin prop
     */
    attached: _propTypes2.default.PropTypes.oneOf(["top", "bottom"]),
    fixed: _propTypes2.default.bool,
    /**
     * semantic-ui builtin prop
     */
    padded: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.bool]),
    /**
     * semantic-ui builtin prop
     */
    singleLine: _propTypes2.default.bool,
    /**
     * semantic-ui builtin prop
     */
    stackable: _propTypes2.default.bool,
    /**
     * semantic-ui builtin prop
     */
    verticalAlign: _propTypes2.default.oneOf(['bottom', 'middle', 'top']),
    /**
     * not done yet
     */
    structured: _propTypes2.default.bool,
    /**
     * checkBox default values , should be an array
     */
    defaultCheckedIds: _propTypes2.default.array,
    /**
     * set particular as green color to highlight
     * param is the data of each row
     *
     * rowHighLightFunction(rowData){
     *    return row.id === "some id"
     * }
     * return true, then set the row to green color
     */
    rowHighLightFunction: _propTypes2.default.func,
    /**
     * this will disable pagination,
     * so we can use our database pagination
     * to saving time
     */
    fakePagination: _propTypes2.default.bool,
    /**
     * pagination call back function
     */
    onPageChangeCallBack: _propTypes2.default.func,
    /**
     * fake pagination need a data sum count
     */
    fakeDataSum: _propTypes2.default.number,
    /**
     * sometimes, we have to re-render the row
     */
    rowRenderCallback: _propTypes2.default.func,
    /**
     * we can set responsive param to re-render the table body
     */
    defaultResponsiveParam: _propTypes2.default.oneOfType([_propTypes2.default.array, _propTypes2.default.object]),
    /**
     * we can add props of pagination bar
     */
    paginationProps: _propTypes2.default.object,
    striped: _propTypes2.default.any
} : {};

var PublicTableFooter = exports.PublicTableFooter = function (_React$Component2) {
    _inherits(PublicTableFooter, _React$Component2);

    function PublicTableFooter(props) {
        _classCallCheck(this, PublicTableFooter);

        var _this3 = _possibleConstructorReturn(this, _React$Component2.call(this, props));

        _this3.state = {};
        return _this3;
    }

    PublicTableFooter.prototype.render = function render() {
        var _props5 = this.props,
            header = _props5.header,
            accessor = _props5.accessor,
            textAlign = _props5.textAlign,
            collapsing = _props5.collapsing;

        return _react2.default.createElement('div', { header: header, accessor: accessor, textAlign: textAlign, collapsing: collapsing });
    };

    return PublicTableFooter;
}(_react2.default.Component);

PublicTableFooter.propTypes = process.env.NODE_ENV !== "production" ? {
    header: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]).isRequired
} : {};

var ColumnCheckBox = exports.ColumnCheckBox = function (_React$Component3) {
    _inherits(ColumnCheckBox, _React$Component3);

    function ColumnCheckBox(props) {
        _classCallCheck(this, ColumnCheckBox);

        var _this4 = _possibleConstructorReturn(this, _React$Component3.call(this, props));

        _this4.toggle = function () {
            var _this4$state = _this4.state,
                checked = _this4$state.checked,
                id = _this4$state.id;

            _this4.setState({ checked: !checked });
            _this4.props.getCallBackId(id);
        };

        _this4.state = {
            checked: props.checked,
            checkBoxStyle: props.checkBoxStyle,
            id: props.id
        };

        return _this4;
    }

    ColumnCheckBox.prototype.componentDidUpdate = function componentDidUpdate(prevProps, prevState, snapshot) {
        //console.log(nextProps)
        var _props6 = this.props,
            id = _props6.id,
            checked = _props6.checked;


        if (id !== prevProps.id) {
            this.setState({
                id: id
            });
        }

        if (checked !== prevProps.checked) {
            this.setState({
                checked: checked
            });
        }
    };

    ColumnCheckBox.prototype.render = function render() {
        var _state4 = this.state,
            checked = _state4.checked,
            checkBoxStyle = _state4.checkBoxStyle;
        //styles¬:[slider,toggle,radio];

        var isSlider = false;
        var isRadio = false;
        var isToggle = false;

        //set check box style.
        if (checkBoxStyle !== undefined) {
            switch (checkBoxStyle) {
                case "slider":
                    isSlider = true;
                    break;
                case "radio":
                    isRadio = true;
                    break;
                case "toggle":
                    isToggle = true;
                    break;
                default:
                    isSlider = false;
                    isRadio = false;
                    isToggle = false;
                    break;
            }
        }

        return _react2.default.createElement(_semanticUiReact.Checkbox, {
            slider: isSlider,
            radio: isRadio,
            toggle: isToggle,
            onChange: this.toggle,
            checked: checked
        });
    };

    return ColumnCheckBox;
}(_react2.default.Component);

//filter the column by given params


ColumnCheckBox.propTypes = process.env.NODE_ENV !== "production" ? {
    id: _propTypes2.default.any,
    checked: _propTypes2.default.bool.isRequired,
    getCallBackId: _propTypes2.default.func.isRequired,
    checkBoxStyle: _propTypes2.default.string
} : {};
function filterDataByFilterContext(columnAccessor, filterContext, dataSet) {

    return _lodash2.default.filter(dataSet, function (ele) {
        //always using toSting() to simplify the compare
        var origin = _lodash2.default.lowerCase(_lodash2.default.toString(ele[columnAccessor])); //"string" === typeof ele[columnAccessor] ? ele[columnAccessor] : ele[columnAccessor].toString();
        var filter = _lodash2.default.lowerCase(_lodash2.default.toString(filterContext)); //"string" === typeof filterContext ? filterContext : filterContext.toString();
        //console.log(origin,filter)
        return _lodash2.default.includes(origin, filter); //origin.includes(filter);
    });
}

function getPageDefaultSize(props) {
    var pagination = props.pagination,
        pageSize = props.pageSize;


    if (pagination === "secondary") {
        return (0, _ObjectsUtils.isStringEmpty)(pageSize) ? 20 : pageSize;
    } else {
        return (0, _ObjectsUtils.isStringEmpty)(pageSize) || ![10, 20, 50].includes(props.pageSize) ? 20 : props.pageSize;
    }
}

/**
 * highlight search text
 *
 * @param text
 * @param highlight
 * @returns {*}
 */
function getHighlightedText(text, highlight) {

    var parts = _lodash2.default.split(text, new RegExp('(' + highlight + ')', 'gi'));

    return _react2.default.createElement(
        'span',
        null,
        parts.map(function (part, i) {
            return _react2.default.createElement(
                'span',
                { key: i,
                    style: _lodash2.default.toLower(part) === _lodash2.default.toLower(highlight) ? {
                        fontWeight: 'bold',
                        backgroundColor: "yellow"
                    } : {} },
                part
            );
        })
    );
}